import Keycloak from 'keycloak-js';
import { useEffect, useRef, useState } from 'react';
import { useAppDispatch } from '../store';

import { authorized } from '../store/authSlice';

type AuthenticationHeader = {
  sessionData: {
    userID: string;
    sessionID: string;
  };
  jwt: string;
};

const domain = import.meta.env.BACKEND_URL;
const useruri = import.meta.env.BACKEND_USER;

export const fetchSettings: RequestInit = {
  method: 'GET',
  credentials: 'include',
  redirect: 'follow',
};

export const useAuth = () => {
  const [isLogin, setLogin] = useState(false);
  const dispatch = useAppDispatch();

  useEffect(() => {
    if (import.meta.env.SKIP_LOGIN) {
      console.warn('skipping login');
      setLogin(true);
      dispatch(
        authorized({
          userID: 'UserID',
          sessionID: 'SessionID',
          jwt: 'jwt',
          authorized: true,
        })
      );
      return;
    }

    fetch(`${domain}${useruri}/headers`, fetchSettings)
      .then((res) =>
        res
          .json()
          .then((res: AuthenticationHeader) => {
            setLogin(true);
            dispatch(
              authorized({
                userID: res.sessionData.userID,
                sessionID: res.sessionData.sessionID,
                jwt: res.jwt,
                authorized: true,
              })
            );
          })
          .catch((err) => {
            console.error(err);
            setLogin(false);
          })
      )
      .catch((err) => {
        console.error(err);
        setLogin(false);
      });
  }, []);

  return isLogin;
};

// export useAuth;
